(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     40010,       1356]
NotebookOptionsPosition[     35704,       1200]
NotebookOutlinePosition[     36362,       1226]
CellTagsIndexPosition[     36234,       1220]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Initialization", "Section",
 CellChangeTimes->{{3.613462869263022*^9, 3.613462876230701*^9}}],

Cell[CellGroupData[{

Cell["<<\"LOOL.m\"", "Input",
 CellChangeTimes->{{3.613462812023279*^9, 3.6134628255828047`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox["\<\"LOOL version: 1.0.1 (14 Jul 2014).\"\>", 
  TraditionalForm]], "Print",
 CellChangeTimes->{3.614319198177079*^9, 3.6143192626152983`*^9, 
  3.6143193080376883`*^9}],

Cell[BoxData[
 FormBox["\<\"http://lool.hepforge.org\"\>", TraditionalForm]], "Print",
 CellChangeTimes->{3.614319198177079*^9, 3.6143192626152983`*^9, 
  3.614319308145074*^9}],

Cell[BoxData[
 FormBox["\<\"Authors: Luka Popov, Amon Ilakovac\"\>", 
  TraditionalForm]], "Print",
 CellChangeTimes->{3.614319198177079*^9, 3.6143192626152983`*^9, 
  3.6143193082057047`*^9}],

Cell[BoxData[
 FormBox["\<\"User manual: arXiv:1407.2727\"\>", TraditionalForm]], "Print",
 CellChangeTimes->{3.614319198177079*^9, 3.6143192626152983`*^9, 
  3.6143193082731123`*^9}],

Cell[BoxData[
 FormBox["\<\"If you use LOOL in a scientific publication or talk, please \
give proper academic credit to us by citing our paper.\"\>", 
  TraditionalForm]], "Print",
 CellChangeTimes->{3.614319198177079*^9, 3.6143192626152983`*^9, 
  3.614319308339699*^9}],

Cell[BoxData[
 FormBox["\<\"The package LOOL is written for Mathematica 8.0 (and higher) \
and it is distributed under the terms of GNU Public License, \
http://www.gnu.org/copyleft/gpl.html\"\>", TraditionalForm]], "Print",
 CellChangeTimes->{3.614319198177079*^9, 3.6143192626152983`*^9, 
  3.6143193084617*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "JInt"}]], "Input",
 CellChangeTimes->{{3.613814558338011*^9, 3.613814559737405*^9}}],

Cell[BoxData[
 StyleBox["\<\"JInt[varlist1,varlist2] returns basic one loop integrals \
\!\(\*SubsuperscriptBox[\(J\), \(\(\\\\ \\\\ \)\(bc .. \)\), \
\(a\)]\)(x,y,...), where varlist1={a,b,c,...} and varlist2=(x,y,...).\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.614319316398821*^9},
 CellTags->"Info3614326516-8918814"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "CompositeF"}]], "Input",
 CellChangeTimes->{{3.613814561738187*^9, 3.613814563881371*^9}}],

Cell[BoxData[
 StyleBox["\<\"CompositeF[fun,varlist] returns numerically-ready composite \
function, where 'fun' is some function composed out of the basic integrals, \
and 'varlist' is list of function's arguments.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.614319317115835*^9},
 CellTags->"Info3614326517-8918814"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic Integrals", "Section",
 CellChangeTimes->{{3.613462880198962*^9, 3.613462882798854*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", "\[Lambda]", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613464255725678*^9, 3.6134642557265778`*^9}, 
   3.614319319754987*^9, {3.614319422890728*^9, 3.6143194230865307`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"log", "(", "\[Lambda]", ")"}]}], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"log", "(", "\[Mu]", ")"}]}], "+", 
     FractionBox["1", "\[Epsilon]"], "-", 
     TagBox["\[DoubledGamma]",
      Function[{}, EulerGamma]], "-", 
     FractionBox["1", "2"], "+", 
     RowBox[{"log", "(", 
      RowBox[{"4", " ", "\[Pi]"}], ")"}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.613464267860672*^9, 3.613464284012656*^9}, 
   3.613465058018024*^9, 3.613896226810669*^9, 3.614319326104631*^9, 
   3.614319427689542*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J13", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", "x", "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"discard", " ", "the", " ", "constant", " ", "term"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.613464683642458*^9, 3.613464695139222*^9}, {
  3.6134648278840733`*^9, 3.613464836582118*^9}, {3.614319332798698*^9, 
  3.6143193494938498`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{"log", "(", "x", ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6134647026603947`*^9, 3.6134648402432337`*^9, 3.6134650617496977`*^9, 
   3.613896229988201*^9, {3.614319336447188*^9, 3.614319352707344*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J13c", "[", "x_", "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{"JInt", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", "x", "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "+", 
   RowBox[{
    RowBox[{"JInt", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", "x", "}"}]}], "]"}], "[", 
    RowBox[{"[", "2", "]"}], "]"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{"keep", " ", "the", " ", "constant", " ", "term"}], " ", 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.61346484295268*^9, 3.613464863079023*^9}, {
  3.614319338911812*^9, 3.614319357839719*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"2", " ", 
    RowBox[{"log", "(", "\[Mu]", ")"}]}], "-", 
   RowBox[{"log", "(", "x", ")"}], "+", 
   FractionBox["1", "\[Epsilon]"], "-", 
   TagBox["\[DoubledGamma]",
    Function[{}, EulerGamma]], "-", 
   FractionBox["1", "2"], "+", 
   RowBox[{"log", "(", 
    RowBox[{"4", " ", "\[Pi]"}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.613464870812252*^9, 3.61346506785108*^9, 3.613896236029636*^9, {
   3.614319345320031*^9, 3.61431936406463*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["\[Lambda]", "1"], ",", 
     SubscriptBox["\[Lambda]", "2"]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.613464558876472*^9, {3.614319369598391*^9, 3.614319373258917*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      SubsuperscriptBox["\[Lambda]", "1", "2"], "-", 
      SubsuperscriptBox["\[Lambda]", "2", "2"], "+", 
      RowBox[{"2", " ", 
       SubscriptBox["\[Lambda]", "2"], " ", 
       SubscriptBox["\[Lambda]", "1"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"log", "(", 
          SubscriptBox["\[Lambda]", "2"], ")"}], "-", 
         RowBox[{"log", "(", 
          SubscriptBox["\[Lambda]", "1"], ")"}]}], ")"}]}]}], 
     RowBox[{"2", " ", 
      SubscriptBox["\[Lambda]", "1"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SubscriptBox["\[Lambda]", "1"], "-", 
         SubscriptBox["\[Lambda]", "2"]}], ")"}], "3"]}]], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.613464566723793*^9, 3.61346507534389*^9, 
  3.613896243481854*^9, 3.614319381202064*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J031", "[", 
   RowBox[{"a_", ",", "b_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613464550978284*^9, 3.613464550979177*^9}, {
  3.6143193840929413`*^9, 3.614319419532393*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     RowBox[{"log", "(", "a", ")"}]}], "+", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     RowBox[{"log", "(", "b", ")"}]}], "-", 
    SuperscriptBox["b", "2"]}], 
   RowBox[{"2", " ", "a", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"a", "-", "b"}], ")"}], "3"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.6134645707666197`*^9, 3.6134650791874332`*^9, 3.6138962473256903`*^9, {
   3.614319393893277*^9, 3.61431942357835*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "w", ",", "z"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["y", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"log", "(", "y", ")"}], "-", 
         RowBox[{"log", "(", "x", ")"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", 
         RowBox[{"3", " ", "y"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}]}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "3"]}]], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.613464380215066*^9, 3.613464426511499*^9, 
  3.613465085641758*^9, 3.613896253697117*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J131", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "w", ",", "z"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613464375195574*^9, 3.6134643751966248`*^9}, 
   3.613464448893691*^9}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["y", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"log", "(", "y", ")"}], "-", 
       RowBox[{"log", "(", "x", ")"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", 
       RowBox[{"3", " ", "y"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}]}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], "3"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.613464452195142*^9, 3.613465088566703*^9, 
  3.613896256758836*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         RowBox[{"5", " ", "x", " ", "y"}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
      RowBox[{"6", " ", "x", " ", 
       SuperscriptBox["y", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"log", "(", "x", ")"}], "-", 
         RowBox[{"log", "(", "y", ")"}]}], ")"}]}]}], 
     RowBox[{"6", " ", "x", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "4"]}]], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6134645869317408`*^9, 3.613465096914584*^9, 
  3.6138962650426283`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J141", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613464569298005*^9, 3.613464569299077*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"5", " ", "x", " ", "y"}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["y", "2"]}]}], ")"}]}], "+", 
    RowBox[{"6", " ", "x", " ", 
     SuperscriptBox["y", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"log", "(", "x", ")"}], "-", 
       RowBox[{"log", "(", "y", ")"}]}], ")"}]}]}], 
   RowBox[{"6", " ", "x", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6134645830551767`*^9, 3.613465100721443*^9, 
  3.61389626927347*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", "4", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6134629654254303`*^9, 3.613462965426347*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["y", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"log", "(", "x", ")"}], "-", 
         RowBox[{"log", "(", "y", ")"}]}], ")"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["x", "2"]}], "-", 
         RowBox[{"7", " ", "x", " ", "y"}], "+", 
         RowBox[{"11", " ", 
          SuperscriptBox["y", "2"]}]}], ")"}]}]}], 
     RowBox[{"6", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "4"]}]], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.613463133382159*^9, 3.613465108063251*^9, 
  3.613896276542079*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J241", "[", 
   RowBox[{"x_", ",", "y_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6134629749136553`*^9, 3.613462974914514*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"6", " ", 
     SuperscriptBox["y", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"log", "(", "x", ")"}], "-", 
       RowBox[{"log", "(", "y", ")"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["x", "2"]}], "-", 
       RowBox[{"7", " ", "x", " ", "y"}], "+", 
       RowBox[{"11", " ", 
        SuperscriptBox["y", "2"]}]}], ")"}]}]}], 
   RowBox[{"6", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], "4"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6134631411681137`*^9, 3.6134651109583807`*^9, 
  3.613896279442066*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613464759346684*^9, 3.613464764635045*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"log", "(", "x", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "y"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["y", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "z"}], ")"}], " ", 
       RowBox[{"log", "(", "y", ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["z", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"y", "-", "x"}], ")"}], " ", 
       RowBox[{"log", "(", "z", ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"x", "-", "y"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"x", "-", "z"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"y", "-", "z"}], ")"}]}]], ",", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"log", "(", "\[Mu]", ")"}]}], "+", 
     FractionBox["1", "\[Epsilon]"], "-", 
     TagBox["\[DoubledGamma]",
      Function[{}, EulerGamma]], "+", "1", "+", 
     RowBox[{"log", "(", 
      RowBox[{"4", " ", "\[Pi]"}], ")"}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6134647706477118`*^9, 3.613465117097806*^9, 
  3.613896285415049*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J1111", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"discard", " ", "the", " ", "constant", " ", "term"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.613464766467516*^9, 3.613464797631205*^9}, {
  3.6134648783508673`*^9, 3.613464884446582*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "y"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "z"}], ")"}], " ", 
     RowBox[{"log", "(", "y", ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"y", "-", "x"}], ")"}], " ", 
     RowBox[{"log", "(", "z", ")"}]}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"x", "-", "y"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", "z"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"y", "-", "z"}], ")"}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.613464801607793*^9, 3.613465120181274*^9, 
  3.613896288502535*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "2", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613462947929398*^9, 3.613462947930285*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"log", "(", "x", ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"y", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["x", "2"], "-", 
         RowBox[{"y", " ", "z"}]}], ")"}]}], "+", 
      RowBox[{"z", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], "2"], " ", 
       RowBox[{"log", "(", "z", ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", " ", 
          RowBox[{"(", 
           RowBox[{"z", "-", "x"}], ")"}], " ", 
          RowBox[{"log", "(", "y", ")"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x", "-", "y"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"y", "-", "z"}], ")"}]}]}], ")"}]}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"x", "-", "z"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"y", "-", "z"}], ")"}]}]], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.613463114505837*^9, 3.613465128627005*^9, 
  3.6138962968813553`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J0211", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "2", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613462951073523*^9, 3.613462951074443*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"log", "(", "x", ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["x", "2"], "-", 
       RowBox[{"y", " ", "z"}]}], ")"}]}], "+", 
    RowBox[{"z", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "y"}], ")"}], "2"], " ", 
     RowBox[{"log", "(", "z", ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"x", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"y", " ", 
        RowBox[{"(", 
         RowBox[{"z", "-", "x"}], ")"}], " ", 
        RowBox[{"log", "(", "y", ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "-", "y"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"y", "-", "z"}], ")"}]}]}], ")"}]}]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "-", "z"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"y", "-", "z"}], ")"}]}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.6134631253464537`*^9, 3.6134651334421873`*^9, 
  3.613896301806041*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613462939529149*^9, 3.613462939529991*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"w", " ", 
        RowBox[{"log", "(", "w", ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"w", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"w", "-", "y"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"w", "-", "z"}], ")"}]}]]}], "+", 
     FractionBox[
      RowBox[{"x", " ", 
       RowBox[{"log", "(", "x", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "z"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"y", " ", 
       RowBox[{"log", "(", "y", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"y", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"y", "-", "z"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{"z", " ", 
       RowBox[{"log", "(", "z", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "y"}], ")"}]}]]}], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.6134630618177137`*^9, 3.613465175572274*^9, 
  3.6138963438238373`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J01111", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_", ",", "w_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613462943513352*^9, 3.613462943514187*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"w", " ", 
      RowBox[{"log", "(", "w", ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "-", "x"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"w", "-", "y"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"w", "-", "z"}], ")"}]}]]}], "+", 
   FractionBox[
    RowBox[{"x", " ", 
     RowBox[{"log", "(", "x", ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "z"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"y", " ", 
     RowBox[{"log", "(", "y", ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", "-", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", "-", "z"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{"z", " ", 
     RowBox[{"log", "(", "z", ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "y"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.6134631031656017`*^9, 3.613465212096868*^9, 
  3.613896380914*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"JInt", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613462924455112*^9, 3.613462924459127*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["w", "2"], " ", 
        RowBox[{"log", "(", "w", ")"}]}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"w", "-", "x"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"w", "-", "y"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"w", "-", "z"}], ")"}]}]]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"log", "(", "x", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "z"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["y", "2"], " ", 
       RowBox[{"log", "(", "y", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "-", "y"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"y", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"y", "-", "z"}], ")"}]}]], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["z", "2"], " ", 
       RowBox[{"log", "(", "z", ")"}]}], 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"w", "-", "z"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "x"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"z", "-", "y"}], ")"}]}]]}], ",", "0"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.613462971580112*^9, 3.613464233836553*^9, 
  3.6134652511624413`*^9, 3.613896419080636*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"J11111", "[", 
   RowBox[{"x_", ",", "y_", ",", "z_", ",", "w_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"JInt", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "1", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z", ",", "w"}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.613462931561595*^9, 3.613462931562504*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["w", "2"], " ", 
      RowBox[{"log", "(", "w", ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"w", "-", "x"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"w", "-", "y"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"w", "-", "z"}], ")"}]}]]}], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     RowBox[{"log", "(", "x", ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"x", "-", "z"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["y", "2"], " ", 
     RowBox[{"log", "(", "y", ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", "-", "y"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"y", "-", "z"}], ")"}]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["z", "2"], " ", 
     RowBox[{"log", "(", "z", ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"w", "-", "z"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "x"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"z", "-", "y"}], ")"}]}]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.61346300819452*^9, 3.613464267656559*^9, 
  3.6134652847267103`*^9, 3.6138964529373407`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Composite functions", "Section",
 CellChangeTimes->{{3.613464290639309*^9, 3.6134642941116657`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"tb", ">", "0"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.613464921535142*^9, 3.613464945506328*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F1", "[", 
    RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
   RowBox[{"CompositeF", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"J11111", "[", 
       RowBox[{"1", ",", "z", ",", "x", ",", "y"}], "]"}], "+", 
      RowBox[{"x", " ", "y", " ", 
       RowBox[{"J01111", "[", 
        RowBox[{"1", ",", "z", ",", "x", ",", "y"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "*", "y"}], ")"}], "/", 
        RowBox[{"tb", "^", "2"}]}], " ", 
       RowBox[{"J0211", "[", 
        RowBox[{"z", ",", "x", ",", "y"}], "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.613464307978759*^9, 3.613464325560121*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F1", "[", 
  RowBox[{"0", ",", "1", ",", "1"}], "]"}]], "Input",
 CellChangeTimes->{{3.613464312772479*^9, 3.613464327490366*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["1", "2"]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.61346432232803*^9, 3.613464329142449*^9}, 
   3.613465297070602*^9, 3.613896465257331*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"F1", "[", 
   RowBox[{"1", ",", "1", ",", "1"}], "]"}], "/.", 
  RowBox[{"tb", "\[Rule]", "10"}]}]], "Input",
 CellChangeTimes->{{3.61346497615405*^9, 3.6134649858748493`*^9}}],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox["33", "200"]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.613464979241681*^9, 3.613464986126925*^9}, 
   3.613465297159502*^9, 3.613896465324286*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F1", "[", 
  RowBox[{"1", ",", "1", ",", "0"}], "]"}]], "Input",
 CellChangeTimes->{{3.613464906052854*^9, 3.613464909698415*^9}}],

Cell[BoxData[
 FormBox["\[Infinity]", TraditionalForm]], "Output",
 CellChangeTimes->{3.613464909957136*^9, 3.61346495851539*^9, 
  3.613464989511167*^9, 3.613465297311286*^9, 3.613896465517437*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"F2", "[", "x_", "]"}], "=", 
   RowBox[{"CompositeF", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"J131", "[", 
       RowBox[{"1", ",", "x"}], "]"}], "+", 
      RowBox[{"J241", "[", 
       RowBox[{"1", ",", "x"}], "]"}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], " ", 
          RowBox[{"J141", "[", 
           RowBox[{"1", ",", "x"}], "]"}]}], "-", 
         RowBox[{"J031", "[", 
          RowBox[{"1", ",", "x"}], "]"}]}], ")"}]}], "+", 
      RowBox[{"5", "/", "6"}]}], ",", 
     RowBox[{"{", "x", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.613464342546071*^9, 3.613464347246746*^9}, {
   3.613464526305358*^9, 3.613464536161436*^9}, 3.6134645878642063`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F2", "[", "0", "]"}]], "Input",
 CellChangeTimes->{{3.613464457813128*^9, 3.6134644593295193`*^9}}],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.613464459616825*^9, 3.613464599863665*^9, 
  3.613464992238817*^9, 3.613465297478692*^9, 3.6138964657397537`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F2", "[", "1", "]"}]], "Input",
 CellChangeTimes->{{3.613464460964016*^9, 3.613464462313204*^9}}],

Cell[BoxData[
 FormBox[
  FractionBox["1", "8"], TraditionalForm]], "Output",
 CellChangeTimes->{3.613464462543975*^9, 3.61346460105772*^9, 
  3.613464992863247*^9, 3.61346529764592*^9, 3.613896465819598*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"F2", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0.998", ",", "1.002"}], "}"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.613464614274859*^9, 3.61346465120357*^9}}],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVzmlQU3cABPAIBKgotpw2OCJjQTAxEaFFbeEPCgQLEcvVQ2RQgkWcahWp
RpRCuEfUEqqtFkTpgFK5JJWKFPKYlquIF0ciRkVBTvU9BEnAGLp82Nn5fdlZ
h137Q2INWCyWCJnvbP/1NYU0TZotPmhwmVaQZUYPfC/CGyKaA7jwtSaJshg+
kC7p5sF9n9XrLsO8S0/HBTDXzUtYA995WM35BL5t76tugdvCA49sgq1mgo0Z
WBb5vdt2uOjqt99sYmiyuPZoWS4c6OaunoKnC04MaeDTw1U5v03QxGIvbRyp
UZC9nNWvvV7TRGfhJmiE1ft93BnY073jsrNWQZ5PmBSfmaSJYNzYKBdOO7t3
NGCKJhVLQqs1cF1d57gWFq2NFe+cUZCs9558WPiGJitSvtP9A48lnXQInqbJ
iWLXQf6sggxxxsPewKfMbaplsGS9cPOvGpoUXLVKn4IvHfE226KliceFY5ej
3irIrucj+pewl2d4VRN84xD/1sUZ/BWHGq/RKUiJ9GDYtlmaKDVfxJ6FuQ2x
plNwfrplmRb250yfKXlLk5Kg0k9j3inIzO8fBwfqaHJ7gZO8BfbZZvFMDx/q
XydZp1cQh6SXgqp3NHF2jxYWwOfuHy4L1dMk27pzVg+XBhXp2HM0CU0+qNsz
pyBBk4lJ5fDi/NSBTtgvt6RvFYsh9eXSUVsWRfjVUeIU2C3Pw1QEx8TThl3w
dEr7uWR44PrWn3gLGJKRzQv5E67yXnM0He42ajAfhVt3Dkh64Zu1oV6cBRRx
sYrbLTBgyEcReT8Hw6rIf+OksNxpbEcqfH+wqK0LXhNznlsD2+q3WPMMGeJ5
oM1+GL5S0XE4GTajNmQtNaBI+iu7ViW83cbEeitc3ryZxzViSEojzyYFXqEe
e3UMtv2jzu4a/Dgt+kIPTEVIhEPwSFNFjDObIbmn6oZsDSnimdduLYV7zy8s
F8GPi8SOffDX7NpEKdzhq/ycZ8yQcWczuRw2SFq6IwM2m/S3GYUzha4ZKrg1
weclx4gi4aHtC1ebMEQlotoC4f2M4LgUzqrUtafAPSv3sXvg+Af2pAa+MTuZ
2AsXPJyyk8MF9yRDSlh2t107b/GPGa198F1ZQs11+HVfQU4/nHOkxbEONpd1
LH4BT7TtWUTBASwXG0NThpQfL33QCfOUlZlGcIZKUnsbXlLprmHDK51E+Xfg
3u3eKlO44txk0D049q8vz5vD7GeE6oal+zKXc2C5pqf0Ibzbb9FpO/hp8pU0
NbxlmWxuGdytPRr9CH7/v8J+e9is2Z7zBC5yvF7sCNc3xp18Nr+n22i5CrZU
b4wfmN/rotKc4XUvFgkHYX7qLTEXpgarWUOwxVchPTx4baf00bzf8FV+fFh8
JezmMKxiR9UK4KgfnH4Zgf9WDzi5wss9tAmj8P9ozmxy
      "]]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->True,
   AxesOrigin->{0.998, 0.12485000000000002`},
   Frame->True,
   PlotRange->{{0.998, 1.002}, {0.12484989992033053`, 0.12514990007951438`}},
   PlotRangeClipping->True,
   PlotRangePadding->{
     Scaled[0.02], 
     Scaled[0.02]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.613464623098373*^9, 3.613464651507557*^9}, 
   3.6134649955158577`*^9, 3.61346529809639*^9, 3.613896466307411*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1036, 988},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"8.0 for Linux x86 (64-bit) (October 10, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3614326516-8918814"->{
  Cell[2334, 76, 340, 6, 45, "Print",
   CellTags->"Info3614326516-8918814"]},
 "Info3614326517-8918814"->{
  Cell[2833, 91, 334, 6, 60, "Print",
   CellTags->"Info3614326517-8918814"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3614326516-8918814", 36024, 1211},
 {"Info3614326517-8918814", 36132, 1214}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 99, 1, 74, "Section"],
Cell[CellGroupData[{
Cell[703, 27, 97, 1, 30, "Input"],
Cell[CellGroupData[{
Cell[825, 32, 192, 4, 24, "Print"],
Cell[1020, 38, 177, 3, 24, "Print"],
Cell[1200, 43, 192, 4, 24, "Print"],
Cell[1395, 49, 183, 3, 24, "Print"],
Cell[1581, 54, 272, 5, 24, "Print"],
Cell[1856, 61, 313, 5, 24, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2218, 72, 113, 2, 30, "Input"],
Cell[2334, 76, 340, 6, 45, "Print",
 CellTags->"Info3614326516-8918814"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2711, 87, 119, 2, 30, "Input"],
Cell[2833, 91, 334, 6, 60, "Print",
 CellTags->"Info3614326517-8918814"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3216, 103, 100, 1, 74, "Section"],
Cell[CellGroupData[{
Cell[3341, 108, 303, 7, 30, "Input"],
Cell[3647, 117, 629, 18, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4313, 140, 547, 15, 30, "Input"],
Cell[4863, 157, 272, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5172, 168, 719, 22, 30, "Input"],
Cell[5894, 192, 516, 14, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6447, 211, 345, 10, 30, "Input"],
Cell[6795, 223, 916, 26, 53, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7748, 254, 448, 13, 30, "Input"],
Cell[8199, 269, 586, 16, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8822, 290, 208, 6, 30, "Input"],
Cell[9033, 298, 745, 24, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9815, 327, 445, 13, 30, "Input"],
Cell[10263, 342, 637, 21, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10937, 368, 188, 6, 30, "Input"],
Cell[11128, 376, 860, 27, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12025, 408, 397, 12, 30, "Input"],
Cell[12425, 422, 765, 24, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13227, 451, 256, 7, 30, "Input"],
Cell[13486, 460, 868, 28, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14391, 493, 399, 12, 30, "Input"],
Cell[14793, 507, 778, 25, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15608, 537, 274, 7, 30, "Input"],
Cell[15885, 546, 1207, 38, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17129, 589, 591, 16, 30, "Input"],
Cell[17723, 607, 831, 27, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18591, 639, 274, 7, 30, "Input"],
Cell[18868, 648, 1362, 44, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20267, 697, 429, 12, 30, "Input"],
Cell[20699, 711, 1238, 41, 54, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21974, 757, 294, 7, 30, "Input"],
Cell[22271, 766, 1451, 48, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23759, 819, 461, 12, 30, "Input"],
Cell[24223, 833, 1312, 45, 51, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25572, 883, 294, 7, 30, "Input"],
Cell[25869, 892, 1588, 52, 52, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27494, 949, 461, 12, 30, "Input"],
Cell[27958, 963, 1447, 49, 52, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29454, 1018, 106, 1, 74, "Section"],
Cell[29563, 1021, 169, 4, 30, "Input"],
Cell[29735, 1027, 792, 22, 30, "Input"],
Cell[CellGroupData[{
Cell[30552, 1053, 154, 3, 30, "Input"],
Cell[30709, 1058, 209, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30955, 1068, 211, 5, 30, "Input"],
Cell[31169, 1075, 213, 5, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31419, 1085, 154, 3, 30, "Input"],
Cell[31576, 1090, 198, 3, 31, "Output"]
}, Open  ]],
Cell[31789, 1096, 811, 23, 30, "Input"],
Cell[CellGroupData[{
Cell[32625, 1123, 123, 2, 30, "Input"],
Cell[32751, 1127, 191, 3, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32979, 1135, 121, 2, 30, "Input"],
Cell[33103, 1139, 208, 4, 47, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33348, 1148, 289, 7, 30, "Input"],
Cell[33640, 1157, 2036, 39, 225, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
